#ifndef NT2_INCLUDE_FUNCTIONS_COMPLEXIFY_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COMPLEXIFY_HPP_INCLUDED

#include <nt2/complex/include/functions/complexify.hpp>

#endif
